import React, { useState } from 'react';
import { View, Text, StyleSheet, Image, TouchableOpacity, Modal } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import { rpx } from '../../utils/rpx';
import BindNavBar from '../../components/BindNavBar';
import QRCodeScanner from 'react-native-qrcode-scanner';
import { RNCamera } from 'react-native-camera';

const BindIndex = () => {
  const [isScanning, setIsScanning] = useState(false);
  const navigation = useNavigation();

  const handlePress = () => {
    setIsScanning(true);
  };

  const onSuccess = (e) => {
    console.log('扫描结果:', e.data);
    setIsScanning(false);
    // 这里处理扫描到的数据
  };

  return (
    <View style={styles.container}>
      <View style={styles.contentArea}>
        <Image 
          source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uVnIDwcwQP7oo12PeYVJ' }} 
          style={styles.Image} 
        />
        <View style={styles.txtbox}>
          <View style={styles.yuan}></View>
          <Text style={styles.txt}>扫描激活码即可</Text>
        </View>
        <TouchableOpacity onPress={handlePress}>
          <View style={styles.addcar}>
            <Image 
              style={styles.add} 
              source={{uri:'https://lxnapi.ccttiot.com/bike/img/static/uvjU3Adq64wqc1TlXjwq'}}
            />
            <Text style={styles.addTxt}>扫码绑车</Text>
          </View>
        </TouchableOpacity>
      </View>
      <BindNavBar />

      <Modal
        visible={isScanning}
        onRequestClose={() => setIsScanning(false)}
        animationType="slide"
      >
        <QRCodeScanner
          onRead={onSuccess}
          flashMode={RNCamera.Constants.FlashMode.auto}
          topContent={
            <Text style={styles.centerText}>
              将二维码放入框内扫描
            </Text>
          }
          bottomContent={
            <TouchableOpacity 
              style={styles.buttonTouchable}
              onPress={() => setIsScanning(false)}
            >
              <Text style={styles.buttonText}>取消扫描</Text>
            </TouchableOpacity>
          }
          containerStyle={styles.scannerContainer}
          cameraStyle={styles.cameraContainer}
        />
      </Modal>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#F3FCFF',
  },
  addTxt: {
    marginLeft: rpx(20),
    fontWeight: '500',
    color: '#ffffff',
    fontSize: rpx(40),
    marginRight: rpx(10),
  },
  addcar: {
    marginTop: rpx(122),
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    width: rpx(641),
    height: rpx(92),
    backgroundColor: '#4297F3',
    borderRadius: rpx(20),
  },
  add: {
    width: rpx(34),
    height: rpx(34),
  },
  contentArea: {
    flex: 1,
    alignItems: 'center',
  },
  txtbox: {
    width: rpx(440),
    justifyContent: 'center',
    flexDirection: 'row',
    alignItems: 'center',
  },
  txt: {
    marginLeft: rpx(14),
    fontSize: rpx(28),
    fontWeight: '400',
    color: '#3D3D3D',
  },
  yuan: {
    width: rpx(22),
    height: rpx(22),
    borderRadius: rpx(11),
    backgroundColor: 'rgba(255, 130, 130, 1)',
  },
  Image: {
    marginTop: rpx(178),
    width: rpx(440),
    height: rpx(340)
  },
  scannerContainer: {
    flex: 1,
    backgroundColor: '#000',
  },
  centerText: {
    fontSize: rpx(28),
    color: '#ffffff',
    marginBottom: rpx(20),
  },
  buttonText: {
    fontSize: rpx(28),
    color: '#ffffff',
  },
  buttonTouchable: {
    padding: rpx(32),
    backgroundColor: '#4297F3',
    borderRadius: rpx(10),
    marginTop: rpx(32),
  },
  cameraContainer: {
    height: rpx(800),
  },
});

export default BindIndex;