import React, { useState } from 'react';
import { 
    View, 
    StyleSheet, 
    TextInput, 
    TouchableWithoutFeedback, 
    Keyboard, 
    Text, 
    TouchableOpacity,
    Alert 
} from 'react-native';
import { useNavigation } from '@react-navigation/native';
import { StackNavigationProp } from '@react-navigation/stack';
import BindNavBar from '../../components/BindNavBar';
import { rpx } from '../../utils/rpx';

// 添加类型定义
type RootStackParamList = {
    Home: undefined;
    DeviceList: undefined;
    BindIndex: undefined;
    SnBind: undefined;
    ConfirmBind: {
        sn: string;
    };
};

type NavigationProp = StackNavigationProp<RootStackParamList>;

const SnBind = () => {
    const navigation = useNavigation<NavigationProp>();
    const [sn, setSn] = useState('');

    const handlePress = () => {
        if (!sn.trim()) {
            Alert.alert(
                '提示',
                '请输入SN码',
                [{ text: '确定' }]
            );
            return;
        }
        navigation.navigate('ConfirmBind', { sn: sn.trim() });
    };

    return (
        <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
            <View style={styles.container}>
                <View style={styles.contentArea}>
                    <View style={styles.IptBox}>
                        <TextInput
                            style={styles.input}
                            placeholder="请输入SN"
                            value={sn}
                            onChangeText={setSn}
                        />
                    </View>
                    <View style={styles.tip}>
                        <Text style={styles.txt}>输入对应二维码下方的激活码</Text>
                    </View>
                    <TouchableOpacity onPress={handlePress}>
                        <View style={styles.addcar}>
                            <Text style={styles.addTxt}>确认绑定</Text>
                        </View>
                    </TouchableOpacity>
                </View>
                <BindNavBar />
            </View>
        </TouchableWithoutFeedback>
    );
};

const styles = StyleSheet.create({
    addTxt: {
        marginLeft: rpx(20),
        fontWeight: '500',
        color: '#ffffff',
        fontSize: rpx(40),
        marginRight: rpx(10),
    },
    addcar: {
        width: rpx(641),
        height: rpx(92),
        marginTop: rpx(122),
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        backgroundColor: '#4297F3',
        borderRadius: rpx(20),
    },
    add: {
        width: rpx(34),
        height: rpx(34),
    },
    txt: {
        fontWeight: '400',
        color: '#3D3D3D',
        fontSize: rpx(32)
    },
    tip: {
        marginTop: rpx(40),
        paddingLeft: rpx(32),
        width: rpx(750)
    },
    input: {
        flex: 1,
        paddingHorizontal: rpx(30),
        fontSize: rpx(28),
    },
    IptBox: {
        width: rpx(688),
        height: rpx(128),
        borderRadius: rpx(30),
        backgroundColor: '#ffffff'
    },
    container: {
        flex: 1,
        backgroundColor: '#F3FCFF',
    },
    contentArea: {
        flex: 1,
        alignItems: 'center'
    },
});

export default SnBind;